@@ -66,6 +66,8 @@ def predict_model(config: dict, fun_control: dict) -> Tuple[float, float]:
     config_id = generate_config_id(config, timestamp=False) + "_TEST"
     dm = LightDataModule(
         dataset=fun_control["data_set"],
+        data_full_train=fun_control["data_full_train"],
+        data_test=fun_control["data_test"],
         batch_size=config["batch_size"],
         num_workers=fun_control["num_workers"],
         test_size=fun_control["test_size"],
